package X3D::FieldTypes::MFColorRGBA;

our $VERSION = '0.009';

use X3D::Package 'MFColorRGBA : X3DArrayField { [] }';

1;
__END__
